<template>
  <a-card :bordered='false'>
    <!-- 查询区域 -->
    <div class='table-page-search-wrapper'>
      <a-form layout='inline' @keyup.enter.native='searchQuery'>
        <a-row :gutter='24'>
          <a-col :xl='6' :lg='7' :md='8' :sm='24'>
            <a-form-item label='检测项目'>
              <j-search-select-tag placeholder='请选择检测项目' v-model='queryParam.itemId'
                                   :dictOptions='itemOptions' />
            </a-form-item>
          </a-col>

          <a-col :xl='6' :lg='7' :md='8' :sm='24'>
            <a-form-item label='检测样本'>
              <j-search-select-tag placeholder='请选择检测样本' v-model='queryParam.sampleId'
                                   :dictOptions='sampleOptions' />
            </a-form-item>
          </a-col>

          <a-col :xl='6' :lg='7' :md='8' :sm='24'>
            <a-form-item label='测试条件'>
              <j-search-select-tag placeholder='请选择测试条件' v-model='queryParam.cond'
                                   :dictOptions='condOptions' />
            </a-form-item>
          </a-col>

          <a-col :xl='6' :lg='7' :md='8' :sm='24'>
            <span style='float: left;overflow: hidden;' class='table-page-search-submitButtons'>
              <a-button type='primary' @click='searchQuery' icon='search'>查询</a-button>
              <a-button type='primary' @click='searchReset' icon='reload' style='margin-left: 8px'>重置</a-button>
              <a @click='handleToggleSearch' style='margin-left: 8px'>
                {{ toggleSearchStatus ? '收起' : '展开' }}
                <a-icon :type="toggleSearchStatus ? 'up' : 'down'" />
              </a>
            </span>
          </a-col>
        </a-row>
      </a-form>
    </div>
    <!-- 查询区域-END -->

    <!-- 操作按钮区域 -->
    <div class='table-operator'>
      <a-button @click='handleAdd' type='primary' icon='plus' disabled>新增</a-button>
      <a-button type='primary' icon='download' @click="handleExportXls('lims_batch_detail')">导出</a-button>
      <a-upload name='file' :showUploadList='false' :multiple='false' :headers='tokenHeader' :action='importExcelUrl'
                @change='handleImportExcel'>
        <a-button type='primary' icon='import' disabled>导入</a-button>
      </a-upload>
      <!-- 高级查询区域 -->
      <j-super-query :fieldList='superFieldList' ref='superQueryModal'
                     @handleSuperQuery='handleSuperQuery'></j-super-query>
      <a-dropdown v-if='selectedRowKeys.length > 0'>
        <a-menu slot='overlay'>
          <a-menu-item key='1' @click='batchDel'>
            <a-icon type='delete' />
            删除
          </a-menu-item>
        </a-menu>
        <a-button style='margin-left: 8px'> 批量操作
          <a-icon type='down' />
        </a-button>
      </a-dropdown>
    </div>

    <!-- table区域-begin -->
    <div>
      <div class='ant-alert ant-alert-info' style='margin-bottom: 16px;'>
        <i class='anticon anticon-info-circle ant-alert-icon'></i> 已选择 <a
        style='font-weight: 600'>{{ selectedRowKeys.length }}</a>项
        <a style='margin-left: 24px' @click='onClearSelected'>清空</a>
      </div>

      <a-table
        ref='table'
        size='middle'
        :scroll='{x:true}'
        bordered
        rowKey='id'
        :columns='columns'
        :dataSource='dataSource'
        :pagination='ipagination'
        :loading='loading'
        :rowSelection='{selectedRowKeys: selectedRowKeys, onChange: onSelectChange}'
        class='j-table-force-nowrap'
        @change='handleTableChange'>

        <template slot='htmlSlot' slot-scope='text'>
          <div v-html='text'></div>
        </template>
        <template slot='imgSlot' slot-scope='text'>
          <span v-if='!text' style='font-size: 12px;font-style: italic;'>无图片</span>
          <img v-else :src='getImgView(text)' height='25px' alt=''
               style='max-width:80px;font-size: 12px;font-style: italic;' />
        </template>
        <template slot='fileSlot' slot-scope='text'>
          <span v-if='!text' style='font-size: 12px;font-style: italic;'>无文件</span>
          <a-button
            v-else
            :ghost='true'
            type='primary'
            icon='download'
            size='small'
            @click='downloadFile(text)'>
            下载
          </a-button>
        </template>

        <span slot='action' slot-scope='text, record'>
          <a @click='handleEdit(record)'>编辑</a>

          <a-divider type='vertical' />
          <a-dropdown>
            <a class='ant-dropdown-link'>更多 <a-icon type='down' /></a>
            <a-menu slot='overlay'>
              <a-menu-item>
                <a @click='handleDetail(record)'>详情</a>
              </a-menu-item>
              <a-menu-item>
                <a-popconfirm title='确定删除吗?' @confirm='() => handleDelete(record.id)'>
                  <a>删除</a>
                </a-popconfirm>
              </a-menu-item>
            </a-menu>
          </a-dropdown>
        </span>

      </a-table>
    </div>

    <lims-batch-detail-modal ref='modalForm' @ok='modalFormOk'></lims-batch-detail-modal>
  </a-card>
</template>

<script>

import '@/assets/less/TableExpand.less'
import { mixinDevice } from '@/utils/mixin'
import { JeecgListMixin } from '@/mixins/JeecgListMixin'
import LimsBatchDetailModal from './modules/LimsBatchDetailModal'

export default {
  name: 'LimsBatchDetailList',
  mixins: [JeecgListMixin, mixinDevice],
  components: {
    LimsBatchDetailModal
  },
  data() {
    return {
      description: 'lims_batch_detail管理页面',
      disableMixinCreated: true,
      // 表头
      columns: [
        {
          title: '#',
          dataIndex: '',
          key: 'rowIndex',
          width: 60,
          align: 'center',
          customRender: function(t, r, index) {
            return parseInt(index) + 1
          }
        },
        {
          title: '检验结果记录ID',
          align: 'center',
          dataIndex: 'resultId'
        },
        {
          title: '检测项目',
          align: 'center',
          dataIndex: 'itemName'
        },
        {
          title: '检验样本',
          align: 'center',
          dataIndex: 'sampleName'
        },

        {
          title: '测试条件',
          align: 'center',
          dataIndex: 'cond'
        },
        {
          title: '补充条件',
          align: 'center',
          dataIndex: 'cond2'
        },
        {
          title: '测试值',
          align: 'center',
          dataIndex: 'value'
        },
        {
          title: '描述',
          align: 'center',
          dataIndex: 'description'
        },
        {
          title: '图片说明',
          align: 'center',
          dataIndex: 'picture'
        },
        {
          title: '破坏性实验',
          align: 'center',
          dataIndex: 'destroy',
          customRender: function(t, r, index) {
            if (t == null || t == '') return ''
            return t == 1 ? '破坏前' : '破坏后'
          }
        },

        {
          title: '备注',
          align: 'center',
          dataIndex: 'remark'
        },
        {
          title: '操作',
          dataIndex: 'action',
          align: 'center',
          fixed: 'right',
          width: 147,
          scopedSlots: { customRender: 'action' }
        }
      ],
      url: {
        list: '/lims/testing/detail/list',
        delete: '/lims/testing/detail/delete',
        deleteBatch: '/lims/testing/detail/deleteBatch',
        exportXlsUrl: '/lims/testing/detail/exportXls',
        importExcelUrl: '/lims/testing/detail/importExcel'

      },
      isorter: {
        column: 'itemId',
        order: 'asc'
      },
      dictOptions: {},
      superFieldList: []
    }
  },
  created() {
    this.getSuperFieldList()
    if (!this.batchResult.id) {
      this.$message.error('异常错误，请退出重试!')
      return false
    }
    this.queryParam.resultId = this.batchResult.id
    this.loadData()
    //初始化字典配置 在自己页面定义
    this.initDictConfig()
  },
  computed: {
    importExcelUrl: function() {
      return `${window._CONFIG['domianURL']}/${this.url.importExcelUrl}`
    },
    batchResult() {
      return {
        id: this.$route.query.id
      }
    },
    itemOptions() {

      let data = this.dataSource
      let result = []

      let list = data.map(item => {
        let obj = { 'text': item.itemName, 'value': item.itemId }
        let itm = result.find(i => i.value == item.itemId)
        if (!itm) {
          result.push(obj)
        }
        return obj
      })

      return result
    },
    sampleOptions() {

      let data = this.dataSource
      let result = []

      let list = data.map(item => {
        let obj = { 'text': item.sampleName, 'value': item.sampleId }
        let sample = result.find(i => i.value == item.sampleId)
        if (!sample) {
          result.push(obj)
        }
        return obj
      })

      return result
    },
    condOptions() {

      let data = this.dataSource
      let result = []

      let list = data.map(item => {
        let obj = { 'text': item.cond, 'value': item.cond }
        let cond = result.find(i => i.value == item.cond)
        if (!cond) {
          result.push(obj)
        }
        return obj
      })

      return result
    }

  },
  methods: {
    searchReset() {
      this.queryParam = {}
      if (!this.batchResult.id) {
        this.$message.error('异常错误，请退出重试!')
        return false
      }
      this.queryParam.resultId = this.batchResult.id
      this.loadData(1)
    },
    initDictConfig() {
    },
    getSuperFieldList() {
      let fieldList = []
      fieldList.push({ type: 'string', value: 'resultId', text: '检验结果记录ID' })
      fieldList.push({ type: 'string', value: 'sampleId', text: '检验样本ID' })
      fieldList.push({ type: 'string', value: 'itemId', text: '检测项目' })
      fieldList.push({ type: 'string', value: 'cond', text: '测试条件' })
      fieldList.push({ type: 'string', value: 'cond2', text: '补充条件' })
      fieldList.push({ type: 'number', value: 'value', text: '测试值' })
      fieldList.push({ type: 'string', value: 'desc', text: '描述' })
      fieldList.push({ type: 'string', value: 'picture', text: '图片说明' })
      fieldList.push({ type: 'string', value: 'remark', text: '备注' })
      this.superFieldList = fieldList
    }
  }
}
</script>
<style scoped>
@import '~@assets/less/common.less';
</style>